@@ -127,7 +127,7 @@ class DataVarsBuilderLinux(linux.LinuxDataVars):
             re_stage = re.compile(r"stage(\d)-(amd64|x86)-(\d{8}).tar.\w+")
             m = re_stage.search(fn)
             if m:
-                map_arch = {'amd64': 'x86_64', 'x86': 'i686'}
+                map_arch = {'amd64': 'x86_64'}
                 c = {'os_linux_build': m.group(3),
                      'os_arch_machine': map_arch[m.group(2)],
                      'os_linux_shortname': 'Gentoo',
@@ -279,7 +279,7 @@ class VariableOsBuilderArchMachine(BuilderLinux):
             if path.exists(path.join(prefix, 'lib64')):
                 return 'x86_64'
             else:
-                return 'i686'
+                return ''
         return ""
 
 
@@ -290,7 +290,7 @@ class VariableOsProfileArchMachine(ReadonlyVariable):
         if path.exists(path.join(self.systemRoot, 'lib64')):
             return 'x86_64'
         else:
-            return 'i686'
+            return ''
 
 
 class VariableOsBuilderLinuxFiles(BuilderLinux):
